@@ -142,7 +142,9 @@ artixpkg_repo_import() {
         esac
     done
 
-    update_patches
+    if ! (( NP )); then
+        update_patches
+    fi
 
     pkgbases+=("$@")
 
@@ -159,17 +161,18 @@ artixpkg_repo_import() {
                 upstream="${arch_map["$pkgbase"]:-$pkgbase}"
 
                 stat_busy "Checking for upstream url"
-                if ! git config --local --get remote.upstream.url &>/dev/null; then
+                if ! git config get remote.upstream.url &>/dev/null; then
                     git remote add upstream "${GIT_UPSTREAM_URL}/${upstream}".git
                 fi
                 stat_done
 
-                msg2 "Fetching upstream tags"
-                local fetch
-                fetch=$(git fetch --tags upstream main  &>/dev/null)
+                stat_busy "Fetching upstream tags"
+                git fetch -fq --prune --tags upstream main
+                stat_done
 
                 local latest version
                 latest=$(git describe --tags FETCH_HEAD)
+
                 version="${latest}"
                 if [[ -n "${TAG}" ]]; then
                     version="${TAG}"
@@ -181,16 +184,16 @@ artixpkg_repo_import() {
                         warning "Could not query ${REPO_DB}"
                     fi
 
-                    git checkout "${version}" -b "${version}" &>/dev/null
+                    git checkout -q "${version}" -b "${version}"
                     local temp
                     temp=$(mktemp -d --tmpdir "${pkgbase}.XXXXXXXXXX")
 
-                    rsync "${rsync_args[@]}" "$(pwd)"/ "${temp}"/ &>/dev/null
-                    git checkout master &>/dev/null
-                    git branch -D "${version}" &>/dev/null
+                    rsync "${rsync_args[@]}" -q "$(pwd)"/ "${temp}"/
+                    git checkout -q master
+                    git branch -q -D "${version}"
 
                     msg "Importing upstream changeset for ${version}"
-                    rsync "${rsync_args[@]}" "${temp}"/ "$(pwd)"/ #&>/dev/null
+                    rsync "${rsync_args[@]}" "${temp}"/ "$(pwd)"/
 
                     if ! (( NP )); then
                         msg2 "Patching ${pkgbase} ..."
